---
name: bug
about: Create a report to help us improve
title: 'bug:'
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environement (please complete the following information):**
 - OS: [e.g. Windows, MacOs]
 - R2X version: [e.g. 0.3.X]

**Additional context**
Add any other context about the problem here.
